#share-notebook-popup {
  display: none;
  position: fixed;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  height: 5em;
  width: 34em;
  border: 1px solid #ABABAB;
  background: #F8F8F8;
  box-shadow: 0px 0px 12px 1px rgba(87, 87, 87, 0.2);
  z-index: 5;
}

#permalink-area {
  position: relative;
  display: flex;
  justify-content: center;
  align-items: center;
  top: 50%;
  left: 50%;
  -webkit-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
}

#permalink-area .btn {
  display: flex;
  margin-left: 2%;
  height: 2em;
}

#permalink-text {
  font-size: 1em;
  height: 2em;
  padding: 0.3em;
  text-align: center;
  width: 25em;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  border: 1px solid #CCCCCC;
  background: #FFFFFF;
}

#close-popup {
  position: absolute;
  display: flex;
  justify-content: center;
  align-items: center;
  background: none;
  border: none;
  top: 0%;
  right: 0%;
}
